@@ -1,26 +1,29 @@
 //    This file is part of ELPA.
 //
-//    The ELPA library was originally created by the ELPA consortium, 
+//    The ELPA library was originally created by the ELPA consortium,
 //    consisting of the following organizations:
 //
-//    - Rechenzentrum Garching der Max-Planck-Gesellschaft (RZG), 
+//    - Rechenzentrum Garching der Max-Planck-Gesellschaft (RZG),
 //    - Bergische Universität Wuppertal, Lehrstuhl für angewandte
 //      Informatik,
 //    - Technische Universität München, Lehrstuhl für Informatik mit
-//      Schwerpunkt Wissenschaftliches Rechnen , 
-//    - Fritz-Haber-Institut, Berlin, Abt. Theorie, 
-//    - Max-Plack-Institut für Mathematik in den Naturwissenschaftrn, 
-//      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition, 
-//      and  
+//      Schwerpunkt Wissenschaftliches Rechnen ,
+//    - Fritz-Haber-Institut, Berlin, Abt. Theorie,
+//    - Max-Plack-Institut für Mathematik in den Naturwissenschaftrn,
+//      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition,
+//      and
 //    - IBM Deutschland GmbH
 //
+//    This particular source code file contains additions, changes and
+//    enhancements authored by Intel Corporation which is not part of
+//    the ELPA consortium.
 //
 //    More information can be found here:
 //    http://elpa.rzg.mpg.de/
 //
 //    ELPA is free software: you can redistribute it and/or modify
-//    it under the terms of the version 3 of the license of the 
-//    GNU Lesser General Public License as published by the Free 
+//    it under the terms of the version 3 of the license of the
+//    GNU Lesser General Public License as published by the Free
 //    Software Foundation.
 //
 //    ELPA is distributed in the hope that it will be useful,
@@ -59,18 +62,23 @@
 #include <complex>
 #include <x86intrin.h>
 
-#ifndef __AVX__
-#ifndef __SSE3__
-#error Neither SSE3 nor AVX are supported, cannot compile file this file
-#endif
-#endif
-
 #define __forceinline __attribute__((always_inline))
 
 #ifdef __USE_AVX128__
 #undef __AVX__
 #endif
 
+#ifdef __FMA4__
+#define __ELPA_USE_FMA__
+#define _mm256_FMADDSUB_pd(a,b,c) _mm256_maddsub_pd(a,b,c)
+#define _mm256_FMSUBADD_pd(a,b,c) _mm256_msubadd_pd(a,b,c)
+#endif
+
+#ifdef __AVX2__
+#define __ELPA_USE_FMA__
+#define _mm256_FMADDSUB_pd(a,b,c) _mm256_fmaddsub_pd(a,b,c)
+#define _mm256_FMSUBADD_pd(a,b,c) _mm256_fmsubadd_pd(a,b,c)
+#endif
 
 extern "C" {
 
@@ -198,7 +206,7 @@ void single_hh_trafo_complex_sse_avx_1hv_(std::complex<double>* q, std::complex<
 	{
 		h1_real = _mm256_broadcast_sd(&hh_dbl[i*2]);
 		h1_imag = _mm256_broadcast_sd(&hh_dbl[(i*2)+1]);
-#ifndef __FMA4__		
+#ifndef __ELPA_USE_FMA__		
 		// conjugate
 		h1_imag = _mm256_xor_pd(h1_imag, sign);
 #endif
@@ -211,38 +219,38 @@ void single_hh_trafo_complex_sse_avx_1hv_(std::complex<double>* q, std::complex<
 		q6 = _mm256_load_pd(&q_dbl[(2*i*ldq)+20]);
 
 		tmp1 = _mm256_mul_pd(h1_imag, q1);
-#ifdef __FMA4__
-		x1 = _mm256_add_pd(x1, _mm256_msubadd_pd(h1_real, q1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x1 = _mm256_add_pd(x1, _mm256_FMSUBADD_pd(h1_real, q1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #else
 		x1 = _mm256_add_pd(x1, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q1), _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #endif
 		tmp2 = _mm256_mul_pd(h1_imag, q2);
-#ifdef __FMA4__
-		x2 = _mm256_add_pd(x2, _mm256_msubadd_pd(h1_real, q2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x2 = _mm256_add_pd(x2, _mm256_FMSUBADD_pd(h1_real, q2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #else
 		x2 = _mm256_add_pd(x2, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q2), _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #endif
 		tmp3 = _mm256_mul_pd(h1_imag, q3);
-#ifdef __FMA4__
-		x3 = _mm256_add_pd(x3, _mm256_msubadd_pd(h1_real, q3, _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x3 = _mm256_add_pd(x3, _mm256_FMSUBADD_pd(h1_real, q3, _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
 #else
 		x3 = _mm256_add_pd(x3, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q3), _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
 #endif
 		tmp4 = _mm256_mul_pd(h1_imag, q4);
-#ifdef __FMA4__
-		x4 = _mm256_add_pd(x4, _mm256_msubadd_pd(h1_real, q4, _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x4 = _mm256_add_pd(x4, _mm256_FMSUBADD_pd(h1_real, q4, _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
 #else
 		x4 = _mm256_add_pd(x4, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q4), _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
 #endif
 		tmp5 = _mm256_mul_pd(h1_imag, q5);
-#ifdef __FMA4__
-		x5 = _mm256_add_pd(x5, _mm256_msubadd_pd(h1_real, q5, _mm256_shuffle_pd(tmp5, tmp5, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x5 = _mm256_add_pd(x5, _mm256_FMSUBADD_pd(h1_real, q5, _mm256_shuffle_pd(tmp5, tmp5, 0x5)));
 #else
 		x5 = _mm256_add_pd(x5, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q5), _mm256_shuffle_pd(tmp5, tmp5, 0x5)));
 #endif
 		tmp6 = _mm256_mul_pd(h1_imag, q6);
-#ifdef __FMA4__
-		x6 = _mm256_add_pd(x6, _mm256_msubadd_pd(h1_real, q6, _mm256_shuffle_pd(tmp6, tmp6, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x6 = _mm256_add_pd(x6, _mm256_FMSUBADD_pd(h1_real, q6, _mm256_shuffle_pd(tmp6, tmp6, 0x5)));
 #else
 		x6 = _mm256_add_pd(x6, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q6), _mm256_shuffle_pd(tmp6, tmp6, 0x5)));
 #endif
@@ -254,38 +262,38 @@ void single_hh_trafo_complex_sse_avx_1hv_(std::complex<double>* q, std::complex<
 	h1_imag = _mm256_xor_pd(h1_imag, sign);
 
 	tmp1 = _mm256_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
-	x1 = _mm256_maddsub_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x1 = _mm256_FMADDSUB_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5));
 #else
 	x1 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x1), _mm256_shuffle_pd(tmp1, tmp1, 0x5));
 #endif
 	tmp2 = _mm256_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
-	x2 = _mm256_maddsub_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x2 = _mm256_FMADDSUB_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5));
 #else
 	x2 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x2), _mm256_shuffle_pd(tmp2, tmp2, 0x5));
 #endif
 	tmp3 = _mm256_mul_pd(h1_imag, x3);
-#ifdef __FMA4__
-	x3 = _mm256_maddsub_pd(h1_real, x3, _mm256_shuffle_pd(tmp3, tmp3, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x3 = _mm256_FMADDSUB_pd(h1_real, x3, _mm256_shuffle_pd(tmp3, tmp3, 0x5));
 #else
 	x3 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x3), _mm256_shuffle_pd(tmp3, tmp3, 0x5));
 #endif
 	tmp4 = _mm256_mul_pd(h1_imag, x4);
-#ifdef __FMA4__
-	x4 = _mm256_maddsub_pd(h1_real, x4, _mm256_shuffle_pd(tmp4, tmp4, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x4 = _mm256_FMADDSUB_pd(h1_real, x4, _mm256_shuffle_pd(tmp4, tmp4, 0x5));
 #else
 	x4 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x4), _mm256_shuffle_pd(tmp4, tmp4, 0x5));
 #endif
 	tmp5 = _mm256_mul_pd(h1_imag, x5);
-#ifdef __FMA4__
-	x5 = _mm256_maddsub_pd(h1_real, x5, _mm256_shuffle_pd(tmp5, tmp5, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x5 = _mm256_FMADDSUB_pd(h1_real, x5, _mm256_shuffle_pd(tmp5, tmp5, 0x5));
 #else
 	x5 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x5), _mm256_shuffle_pd(tmp5, tmp5, 0x5));
 #endif
 	tmp6 = _mm256_mul_pd(h1_imag, x6);
-#ifdef __FMA4__
-	x6 = _mm256_maddsub_pd(h1_real, x6, _mm256_shuffle_pd(tmp6, tmp6, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x6 = _mm256_FMADDSUB_pd(h1_real, x6, _mm256_shuffle_pd(tmp6, tmp6, 0x5));
 #else
 	x6 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x6), _mm256_shuffle_pd(tmp6, tmp6, 0x5));
 #endif
@@ -324,38 +332,38 @@ void single_hh_trafo_complex_sse_avx_1hv_(std::complex<double>* q, std::complex<
 		q6 = _mm256_load_pd(&q_dbl[(2*i*ldq)+20]);
 
 		tmp1 = _mm256_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
-		q1 = _mm256_add_pd(q1, _mm256_maddsub_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q1 = _mm256_add_pd(q1, _mm256_FMADDSUB_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #else
 		q1 = _mm256_add_pd(q1, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x1), _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #endif
 		tmp2 = _mm256_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
-		q2 = _mm256_add_pd(q2, _mm256_maddsub_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q2 = _mm256_add_pd(q2, _mm256_FMADDSUB_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #else
 		q2 = _mm256_add_pd(q2, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x2), _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #endif
 		tmp3 = _mm256_mul_pd(h1_imag, x3);
-#ifdef __FMA4__	
-		q3 = _mm256_add_pd(q3, _mm256_maddsub_pd(h1_real, x3, _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
+#ifdef __ELPA_USE_FMA__	
+		q3 = _mm256_add_pd(q3, _mm256_FMADDSUB_pd(h1_real, x3, _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
 #else
 		q3 = _mm256_add_pd(q3, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x3), _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
 #endif
 		tmp4 = _mm256_mul_pd(h1_imag, x4);
-#ifdef __FMA4__
-		q4 = _mm256_add_pd(q4, _mm256_maddsub_pd(h1_real, x4, _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q4 = _mm256_add_pd(q4, _mm256_FMADDSUB_pd(h1_real, x4, _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
 #else
 		q4 = _mm256_add_pd(q4, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x4), _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
 #endif
 		tmp5 = _mm256_mul_pd(h1_imag, x5);
-#ifdef __FMA4__
-		q5 = _mm256_add_pd(q5, _mm256_maddsub_pd(h1_real, x5, _mm256_shuffle_pd(tmp5, tmp5, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q5 = _mm256_add_pd(q5, _mm256_FMADDSUB_pd(h1_real, x5, _mm256_shuffle_pd(tmp5, tmp5, 0x5)));
 #else
 		q5 = _mm256_add_pd(q5, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x5), _mm256_shuffle_pd(tmp5, tmp5, 0x5)));
 #endif
 		tmp6 = _mm256_mul_pd(h1_imag, x6);
-#ifdef __FMA4__
-		q6 = _mm256_add_pd(q6, _mm256_maddsub_pd(h1_real, x6, _mm256_shuffle_pd(tmp6, tmp6, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q6 = _mm256_add_pd(q6, _mm256_FMADDSUB_pd(h1_real, x6, _mm256_shuffle_pd(tmp6, tmp6, 0x5)));
 #else
 		q6 = _mm256_add_pd(q6, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x6), _mm256_shuffle_pd(tmp6, tmp6, 0x5)));
 #endif
@@ -391,7 +399,7 @@ static __forceinline void hh_trafo_complex_kernel_8_AVX_1hv(std::complex<double>
 	{
 		h1_real = _mm256_broadcast_sd(&hh_dbl[i*2]);
 		h1_imag = _mm256_broadcast_sd(&hh_dbl[(i*2)+1]);
-#ifndef __FMA4__		
+#ifndef __ELPA_USE_FMA__		
 		// conjugate
 		h1_imag = _mm256_xor_pd(h1_imag, sign);
 #endif
@@ -402,26 +410,26 @@ static __forceinline void hh_trafo_complex_kernel_8_AVX_1hv(std::complex<double>
 		q4 = _mm256_load_pd(&q_dbl[(2*i*ldq)+12]);
 
 		tmp1 = _mm256_mul_pd(h1_imag, q1);
-#ifdef __FMA4__
-		x1 = _mm256_add_pd(x1, _mm256_msubadd_pd(h1_real, q1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x1 = _mm256_add_pd(x1, _mm256_FMSUBADD_pd(h1_real, q1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #else
 		x1 = _mm256_add_pd(x1, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q1), _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #endif
 		tmp2 = _mm256_mul_pd(h1_imag, q2);
-#ifdef __FMA4__
-		x2 = _mm256_add_pd(x2, _mm256_msubadd_pd(h1_real, q2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x2 = _mm256_add_pd(x2, _mm256_FMSUBADD_pd(h1_real, q2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #else
 		x2 = _mm256_add_pd(x2, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q2), _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #endif
 		tmp3 = _mm256_mul_pd(h1_imag, q3);
-#ifdef __FMA4__
-		x3 = _mm256_add_pd(x3, _mm256_msubadd_pd(h1_real, q3, _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x3 = _mm256_add_pd(x3, _mm256_FMSUBADD_pd(h1_real, q3, _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
 #else
 		x3 = _mm256_add_pd(x3, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q3), _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
 #endif
 		tmp4 = _mm256_mul_pd(h1_imag, q4);
-#ifdef __FMA4__
-		x4 = _mm256_add_pd(x4, _mm256_msubadd_pd(h1_real, q4, _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x4 = _mm256_add_pd(x4, _mm256_FMSUBADD_pd(h1_real, q4, _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
 #else
 		x4 = _mm256_add_pd(x4, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q4), _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
 #endif
@@ -433,26 +441,26 @@ static __forceinline void hh_trafo_complex_kernel_8_AVX_1hv(std::complex<double>
 	h1_imag = _mm256_xor_pd(h1_imag, sign);
 
 	tmp1 = _mm256_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
-	x1 = _mm256_maddsub_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x1 = _mm256_FMADDSUB_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5));
 #else
 	x1 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x1), _mm256_shuffle_pd(tmp1, tmp1, 0x5));
 #endif
 	tmp2 = _mm256_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
-	x2 = _mm256_maddsub_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x2 = _mm256_FMADDSUB_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5));
 #else
 	x2 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x2), _mm256_shuffle_pd(tmp2, tmp2, 0x5));
 #endif
 	tmp3 = _mm256_mul_pd(h1_imag, x3);
-#ifdef __FMA4__
-	x3 = _mm256_maddsub_pd(h1_real, x3, _mm256_shuffle_pd(tmp3, tmp3, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x3 = _mm256_FMADDSUB_pd(h1_real, x3, _mm256_shuffle_pd(tmp3, tmp3, 0x5));
 #else
 	x3 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x3), _mm256_shuffle_pd(tmp3, tmp3, 0x5));
 #endif
 	tmp4 = _mm256_mul_pd(h1_imag, x4);
-#ifdef __FMA4__
-	x4 = _mm256_maddsub_pd(h1_real, x4, _mm256_shuffle_pd(tmp4, tmp4, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x4 = _mm256_FMADDSUB_pd(h1_real, x4, _mm256_shuffle_pd(tmp4, tmp4, 0x5));
 #else
 	x4 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x4), _mm256_shuffle_pd(tmp4, tmp4, 0x5));
 #endif
@@ -483,26 +491,26 @@ static __forceinline void hh_trafo_complex_kernel_8_AVX_1hv(std::complex<double>
 		q4 = _mm256_load_pd(&q_dbl[(2*i*ldq)+12]);
 
 		tmp1 = _mm256_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
-		q1 = _mm256_add_pd(q1, _mm256_maddsub_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q1 = _mm256_add_pd(q1, _mm256_FMADDSUB_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #else
 		q1 = _mm256_add_pd(q1, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x1), _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #endif
 		tmp2 = _mm256_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
-		q2 = _mm256_add_pd(q2, _mm256_maddsub_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q2 = _mm256_add_pd(q2, _mm256_FMADDSUB_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #else	
 		q2 = _mm256_add_pd(q2, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x2), _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #endif
 		tmp3 = _mm256_mul_pd(h1_imag, x3);
-#ifdef __FMA4__
-		q3 = _mm256_add_pd(q3, _mm256_maddsub_pd(h1_real, x3, _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q3 = _mm256_add_pd(q3, _mm256_FMADDSUB_pd(h1_real, x3, _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
 #else		
 		q3 = _mm256_add_pd(q3, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x3), _mm256_shuffle_pd(tmp3, tmp3, 0x5)));
 #endif
 		tmp4 = _mm256_mul_pd(h1_imag, x4);
-#ifdef __FMA4__
-		q4 = _mm256_add_pd(q4, _mm256_maddsub_pd(h1_real, x4, _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q4 = _mm256_add_pd(q4, _mm256_FMADDSUB_pd(h1_real, x4, _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
 #else
 		q4 = _mm256_add_pd(q4, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x4), _mm256_shuffle_pd(tmp4, tmp4, 0x5)));
 #endif
@@ -534,7 +542,7 @@ static __forceinline void hh_trafo_complex_kernel_4_AVX_1hv(std::complex<double>
 	{
 		h1_real = _mm256_broadcast_sd(&hh_dbl[i*2]);
 		h1_imag = _mm256_broadcast_sd(&hh_dbl[(i*2)+1]);
-#ifndef __FMA4__
+#ifndef __ELPA_USE_FMA__
 		// conjugate
 		h1_imag = _mm256_xor_pd(h1_imag, sign);
 #endif
@@ -543,14 +551,14 @@ static __forceinline void hh_trafo_complex_kernel_4_AVX_1hv(std::complex<double>
 		q2 = _mm256_load_pd(&q_dbl[(2*i*ldq)+4]);
 
 		tmp1 = _mm256_mul_pd(h1_imag, q1);
-#ifdef __FMA4__
-		x1 = _mm256_add_pd(x1, _mm256_msubadd_pd(h1_real, q1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x1 = _mm256_add_pd(x1, _mm256_FMSUBADD_pd(h1_real, q1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #else
 		x1 = _mm256_add_pd(x1, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q1), _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #endif
 		tmp2 = _mm256_mul_pd(h1_imag, q2);
-#ifdef __FMA4__
-		x2 = _mm256_add_pd(x2, _mm256_msubadd_pd(h1_real, q2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		x2 = _mm256_add_pd(x2, _mm256_FMSUBADD_pd(h1_real, q2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #else
 		x2 = _mm256_add_pd(x2, _mm256_addsub_pd( _mm256_mul_pd(h1_real, q2), _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #endif
@@ -562,14 +570,14 @@ static __forceinline void hh_trafo_complex_kernel_4_AVX_1hv(std::complex<double>
 	h1_imag = _mm256_xor_pd(h1_imag, sign);
 
 	tmp1 = _mm256_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
-	x1 = _mm256_maddsub_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x1 = _mm256_FMADDSUB_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5));
 #else
 	x1 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x1), _mm256_shuffle_pd(tmp1, tmp1, 0x5));
 #endif
 	tmp2 = _mm256_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
-	x2 = _mm256_maddsub_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5));
+#ifdef __ELPA_USE_FMA__
+	x2 = _mm256_FMADDSUB_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5));
 #else
 	x2 = _mm256_addsub_pd( _mm256_mul_pd(h1_real, x2), _mm256_shuffle_pd(tmp2, tmp2, 0x5));
 #endif
@@ -592,14 +600,14 @@ static __forceinline void hh_trafo_complex_kernel_4_AVX_1hv(std::complex<double>
 		q2 = _mm256_load_pd(&q_dbl[(2*i*ldq)+4]);
 
 		tmp1 = _mm256_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
-		q1 = _mm256_add_pd(q1, _mm256_maddsub_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q1 = _mm256_add_pd(q1, _mm256_FMADDSUB_pd(h1_real, x1, _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #else
 		q1 = _mm256_add_pd(q1, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x1), _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #endif
 		tmp2 = _mm256_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
-		q2 = _mm256_add_pd(q2, _mm256_maddsub_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
+#ifdef __ELPA_USE_FMA__
+		q2 = _mm256_add_pd(q2, _mm256_FMADDSUB_pd(h1_real, x2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #else
 		q2 = _mm256_add_pd(q2, _mm256_addsub_pd( _mm256_mul_pd(h1_real, x2), _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #endif
@@ -634,7 +642,7 @@ static __forceinline void hh_trafo_complex_kernel_6_SSE_1hv(std::complex<double>
 	{
 		h1_real = _mm_loaddup_pd(&hh_dbl[i*2]);
 		h1_imag = _mm_loaddup_pd(&hh_dbl[(i*2)+1]);
-#ifndef __FMA4__		
+#ifndef __ELPA_USE_FMA__		
 		// conjugate
 		h1_imag = _mm_xor_pd(h1_imag, sign);
 #endif
@@ -647,37 +655,37 @@ static __forceinline void hh_trafo_complex_kernel_6_SSE_1hv(std::complex<double>
 		q6 = _mm_load_pd(&q_dbl[(2*i*ldq)+10]);
 
 		tmp1 = _mm_mul_pd(h1_imag, q1);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x1 = _mm_add_pd(x1, _mm_msubadd_pd(h1_real, q1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #else
 		x1 = _mm_add_pd(x1, _mm_addsub_pd( _mm_mul_pd(h1_real, q1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp2 = _mm_mul_pd(h1_imag, q2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x2 = _mm_add_pd(x2, _mm_msubadd_pd(h1_real, q2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #else
 		x2 = _mm_add_pd(x2, _mm_addsub_pd( _mm_mul_pd(h1_real, q2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp3 = _mm_mul_pd(h1_imag, q3);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x3 = _mm_add_pd(x3, _mm_msubadd_pd(h1_real, q3, _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1))));
 #else
 		x3 = _mm_add_pd(x3, _mm_addsub_pd( _mm_mul_pd(h1_real, q3), _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp4 = _mm_mul_pd(h1_imag, q4);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x4 = _mm_add_pd(x4, _mm_msubadd_pd(h1_real, q4, _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1))));
 #else
 		x4 = _mm_add_pd(x4, _mm_addsub_pd( _mm_mul_pd(h1_real, q4), _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp5 = _mm_mul_pd(h1_imag, q5);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x5 = _mm_add_pd(x5, _mm_msubadd_pd(h1_real, q5, _mm_shuffle_pd(tmp5, tmp5, _MM_SHUFFLE2(0,1))));
 #else
 		x5 = _mm_add_pd(x5, _mm_addsub_pd( _mm_mul_pd(h1_real, q5), _mm_shuffle_pd(tmp5, tmp5, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp6 = _mm_mul_pd(h1_imag, q6);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x6 = _mm_add_pd(x6, _mm_msubadd_pd(h1_real, q6, _mm_shuffle_pd(tmp6, tmp6, _MM_SHUFFLE2(0,1))));
 #else
 		x6 = _mm_add_pd(x6, _mm_addsub_pd( _mm_mul_pd(h1_real, q6), _mm_shuffle_pd(tmp6, tmp6, _MM_SHUFFLE2(0,1))));
@@ -690,37 +698,37 @@ static __forceinline void hh_trafo_complex_kernel_6_SSE_1hv(std::complex<double>
 	h1_imag = _mm_xor_pd(h1_imag, sign);
 
 	tmp1 = _mm_mul_pd(h1_imag, x1);
-#ifdef __FMA4__	
+#ifdef __ELPA_USE_FMA__	
 	x1 = _mm_maddsub_pd(h1_real, x1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1)));
 #else
 	x1 = _mm_addsub_pd( _mm_mul_pd(h1_real, x1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp2 = _mm_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x2 = _mm_maddsub_pd(h1_real, x2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1)));
 #else
 	x2 = _mm_addsub_pd( _mm_mul_pd(h1_real, x2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp3 = _mm_mul_pd(h1_imag, x3);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x3 = _mm_maddsub_pd(h1_real, x3, _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1)));
 #else
 	x3 = _mm_addsub_pd( _mm_mul_pd(h1_real, x3), _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp4 = _mm_mul_pd(h1_imag, x4);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x4 = _mm_maddsub_pd(h1_real, x4, _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1)));
 #else
 	x4 = _mm_addsub_pd( _mm_mul_pd(h1_real, x4), _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp5 = _mm_mul_pd(h1_imag, x5);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x5 = _mm_maddsub_pd(h1_real, x5, _mm_shuffle_pd(tmp5, tmp5, _MM_SHUFFLE2(0,1)));
 #else
 	x5 = _mm_addsub_pd( _mm_mul_pd(h1_real, x5), _mm_shuffle_pd(tmp5, tmp5, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp6 = _mm_mul_pd(h1_imag, x6);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x6 = _mm_maddsub_pd(h1_real, x6, _mm_shuffle_pd(tmp6, tmp6, _MM_SHUFFLE2(0,1)));
 #else
 	x6 = _mm_addsub_pd( _mm_mul_pd(h1_real, x6), _mm_shuffle_pd(tmp6, tmp6, _MM_SHUFFLE2(0,1)));
@@ -760,37 +768,37 @@ static __forceinline void hh_trafo_complex_kernel_6_SSE_1hv(std::complex<double>
 		q6 = _mm_load_pd(&q_dbl[(2*i*ldq)+10]);
 
 		tmp1 = _mm_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q1 = _mm_add_pd(q1, _mm_maddsub_pd(h1_real, x1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #else
 		q1 = _mm_add_pd(q1, _mm_addsub_pd( _mm_mul_pd(h1_real, x1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp2 = _mm_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q2 = _mm_add_pd(q2, _mm_maddsub_pd(h1_real, x2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #else
 		q2 = _mm_add_pd(q2, _mm_addsub_pd( _mm_mul_pd(h1_real, x2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp3 = _mm_mul_pd(h1_imag, x3);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q3 = _mm_add_pd(q3, _mm_maddsub_pd(h1_real, x3, _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1))));
 #else
 		q3 = _mm_add_pd(q3, _mm_addsub_pd( _mm_mul_pd(h1_real, x3), _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp4 = _mm_mul_pd(h1_imag, x4);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q4 = _mm_add_pd(q4, _mm_maddsub_pd(h1_real, x4, _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1))));
 #else
 		q4 = _mm_add_pd(q4, _mm_addsub_pd( _mm_mul_pd(h1_real, x4), _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp5 = _mm_mul_pd(h1_imag, x5);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q5 = _mm_add_pd(q5, _mm_maddsub_pd(h1_real, x5, _mm_shuffle_pd(tmp5, tmp5, _MM_SHUFFLE2(0,1))));
 #else
 		q5 = _mm_add_pd(q5, _mm_addsub_pd( _mm_mul_pd(h1_real, x5), _mm_shuffle_pd(tmp5, tmp5, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp6 = _mm_mul_pd(h1_imag, x6);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q6 = _mm_add_pd(q6, _mm_maddsub_pd(h1_real, x6, _mm_shuffle_pd(tmp6, tmp6, _MM_SHUFFLE2(0,1))));
 #else
 		q6 = _mm_add_pd(q6, _mm_addsub_pd( _mm_mul_pd(h1_real, x6), _mm_shuffle_pd(tmp6, tmp6, _MM_SHUFFLE2(0,1))));
@@ -827,7 +835,7 @@ static __forceinline void hh_trafo_complex_kernel_4_SSE_1hv(std::complex<double>
 	{
 		h1_real = _mm_loaddup_pd(&hh_dbl[i*2]);
 		h1_imag = _mm_loaddup_pd(&hh_dbl[(i*2)+1]);
-#ifndef __FMA4__
+#ifndef __ELPA_USE_FMA__
 		// conjugate
 		h1_imag = _mm_xor_pd(h1_imag, sign);
 #endif
@@ -838,25 +846,25 @@ static __forceinline void hh_trafo_complex_kernel_4_SSE_1hv(std::complex<double>
 		q4 = _mm_load_pd(&q_dbl[(2*i*ldq)+6]);
 
 		tmp1 = _mm_mul_pd(h1_imag, q1);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x1 = _mm_add_pd(x1, _mm_msubadd_pd(h1_real, q1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #else
 		x1 = _mm_add_pd(x1, _mm_addsub_pd( _mm_mul_pd(h1_real, q1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp2 = _mm_mul_pd(h1_imag, q2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x2 = _mm_add_pd(x2, _mm_msubadd_pd(h1_real, q2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #else
 		x2 = _mm_add_pd(x2, _mm_addsub_pd( _mm_mul_pd(h1_real, q2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp3 = _mm_mul_pd(h1_imag, q3);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x3 = _mm_add_pd(x3, _mm_msubadd_pd(h1_real, q3, _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1))));
 #else
 		x3 = _mm_add_pd(x3, _mm_addsub_pd( _mm_mul_pd(h1_real, q3), _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp4 = _mm_mul_pd(h1_imag, q4);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x4 = _mm_add_pd(x4, _mm_msubadd_pd(h1_real, q4, _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1))));
 #else
 		x4 = _mm_add_pd(x4, _mm_addsub_pd( _mm_mul_pd(h1_real, q4), _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1))));
@@ -869,25 +877,25 @@ static __forceinline void hh_trafo_complex_kernel_4_SSE_1hv(std::complex<double>
 	h1_imag = _mm_xor_pd(h1_imag, sign);
 
 	tmp1 = _mm_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x1 = _mm_maddsub_pd(h1_real, x1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1)));
 #else
 	x1 = _mm_addsub_pd( _mm_mul_pd(h1_real, x1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp2 = _mm_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x2 = _mm_maddsub_pd(h1_real, x2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1)));
 #else
 	x2 = _mm_addsub_pd( _mm_mul_pd(h1_real, x2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp3 = _mm_mul_pd(h1_imag, x3);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x3 = _mm_maddsub_pd(h1_real, x3, _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1)));
 #else
 	x3 = _mm_addsub_pd( _mm_mul_pd(h1_real, x3), _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp4 = _mm_mul_pd(h1_imag, x4);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x4 = _mm_maddsub_pd(h1_real, x4, _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1)));
 #else
 	x4 = _mm_addsub_pd( _mm_mul_pd(h1_real, x4), _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1)));
@@ -919,25 +927,25 @@ static __forceinline void hh_trafo_complex_kernel_4_SSE_1hv(std::complex<double>
 		q4 = _mm_load_pd(&q_dbl[(2*i*ldq)+6]);
 
 		tmp1 = _mm_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q1 = _mm_add_pd(q1, _mm_maddsub_pd(h1_real, x1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #else
 		q1 = _mm_add_pd(q1, _mm_addsub_pd( _mm_mul_pd(h1_real, x1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp2 = _mm_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q2 = _mm_add_pd(q2, _mm_maddsub_pd(h1_real, x2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #else
 		q2 = _mm_add_pd(q2, _mm_addsub_pd( _mm_mul_pd(h1_real, x2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp3 = _mm_mul_pd(h1_imag, x3);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q3 = _mm_add_pd(q3, _mm_maddsub_pd(h1_real, x3, _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1))));
 #else
 		q3 = _mm_add_pd(q3, _mm_addsub_pd( _mm_mul_pd(h1_real, x3), _mm_shuffle_pd(tmp3, tmp3, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp4 = _mm_mul_pd(h1_imag, x4);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q4 = _mm_add_pd(q4, _mm_maddsub_pd(h1_real, x4, _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1))));
 #else
 		q4 = _mm_add_pd(q4, _mm_addsub_pd( _mm_mul_pd(h1_real, x4), _mm_shuffle_pd(tmp4, tmp4, _MM_SHUFFLE2(0,1))));
@@ -970,7 +978,7 @@ static __forceinline void hh_trafo_complex_kernel_2_SSE_1hv(std::complex<double>
 	{
 		h1_real = _mm_loaddup_pd(&hh_dbl[i*2]);
 		h1_imag = _mm_loaddup_pd(&hh_dbl[(i*2)+1]);
-#ifndef __FMA4__	
+#ifndef __ELPA_USE_FMA__	
 		// conjugate
 		h1_imag = _mm_xor_pd(h1_imag, sign);
 #endif
@@ -979,13 +987,13 @@ static __forceinline void hh_trafo_complex_kernel_2_SSE_1hv(std::complex<double>
 		q2 = _mm_load_pd(&q_dbl[(2*i*ldq)+2]);
 
 		tmp1 = _mm_mul_pd(h1_imag, q1);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x1 = _mm_add_pd(x1, _mm_msubadd_pd(h1_real, q1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #else
 		x1 = _mm_add_pd(x1, _mm_addsub_pd( _mm_mul_pd(h1_real, q1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp2 = _mm_mul_pd(h1_imag, q2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		x2 = _mm_add_pd(x2, _mm_msubadd_pd(h1_real, q2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #else
 		x2 = _mm_add_pd(x2, _mm_addsub_pd( _mm_mul_pd(h1_real, q2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
@@ -998,13 +1006,13 @@ static __forceinline void hh_trafo_complex_kernel_2_SSE_1hv(std::complex<double>
 	h1_imag = _mm_xor_pd(h1_imag, sign);
 
 	tmp1 = _mm_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x1 = _mm_maddsub_pd(h1_real, x1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1)));
 #else
 	x1 = _mm_addsub_pd( _mm_mul_pd(h1_real, x1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1)));
 #endif
 	tmp2 = _mm_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 	x2 = _mm_maddsub_pd(h1_real, x2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1)));
 #else
 	x2 = _mm_addsub_pd( _mm_mul_pd(h1_real, x2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1)));
@@ -1028,13 +1036,13 @@ static __forceinline void hh_trafo_complex_kernel_2_SSE_1hv(std::complex<double>
 		q2 = _mm_load_pd(&q_dbl[(2*i*ldq)+2]);
 
 		tmp1 = _mm_mul_pd(h1_imag, x1);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q1 = _mm_add_pd(q1, _mm_maddsub_pd(h1_real, x1, _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #else
 		q1 = _mm_add_pd(q1, _mm_addsub_pd( _mm_mul_pd(h1_real, x1), _mm_shuffle_pd(tmp1, tmp1, _MM_SHUFFLE2(0,1))));
 #endif
 		tmp2 = _mm_mul_pd(h1_imag, x2);
-#ifdef __FMA4__
+#ifdef __ELPA_USE_FMA__
 		q2 = _mm_add_pd(q2, _mm_maddsub_pd(h1_real, x2, _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
 #else
 		q2 = _mm_add_pd(q2, _mm_addsub_pd( _mm_mul_pd(h1_real, x2), _mm_shuffle_pd(tmp2, tmp2, _MM_SHUFFLE2(0,1))));
